==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/inputs/TrafficMirrorFilterRuleSourcePortRangeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin.inputs

import com.pulumi.aws.ec2.inputs.TrafficMirrorFilterRuleSourcePortRangeArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property fromPort Starting port of the range
 * @property toPort Ending port of the range
 */
public data class TrafficMirrorFilterRuleSourcePortRangeArgs(
    public val fromPort: Output<Int>? = null,
    public val toPort: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.aws.ec2.inputs.TrafficMirrorFilterRuleSourcePortRangeArgs> {
    override fun toJava(): com.pulumi.aws.ec2.inputs.TrafficMirrorFilterRuleSourcePortRangeArgs =
        com.pulumi.aws.ec2.inputs.TrafficMirrorFilterRuleSourcePortRangeArgs.builder()
            .fromPort(fromPort?.applyValue({ args0 -> args0 }))
            .toPort(toPort?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TrafficMirrorFilterRuleSourcePortRangeArgs].
 */
@PulumiTagMarker
public class TrafficMirrorFilterRuleSourcePortRangeArgsBuilder internal constructor() {
    private var fromPort: Output<Int>? = null

    private var toPort: Output<Int>? = null

    /**
     * @param value Starting port of the range
     */
    @JvmName("xvgwckrbtawlxmbr")
    public suspend fun fromPort(`value`: Output<Int>) {
        this.fromPort = value
    }

    /**
     * @param value Ending port of the range
     */
    @JvmName("opuofsteewoxraud")
    public suspend fun toPort(`value`: Output<Int>) {
        this.toPort = value
    }

    /**
     * @param value Starting port of the range
     */
    @JvmName("yjoaictecdlphwca")
    public suspend fun fromPort(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fromPort = mapped
    }

    /**
     * @param value Ending port of the range
     */
    @JvmName("lcnxfcbdbbaimnav")
    public suspend fun toPort(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.toPort = mapped
    }

    internal fun build(): TrafficMirrorFilterRuleSourcePortRangeArgs =
        TrafficMirrorFilterRuleSourcePortRangeArgs(
            fromPort = fromPort,
            toPort = toPort,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/inputs/TrafficMirrorFilterRuleSourcePortRangeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin.inputs

import com.pulumi.aws.ec2.inputs.TrafficMirrorFilterRuleSourcePortRangeArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property fromPort Starting port of the range
 * @property toPort Ending port of the range
 */
public data class TrafficMirrorFilterRuleSourcePortRangeArgs(
    public val fromPort: Output<Int>? = null,
    public val toPort: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.aws.ec2.inputs.TrafficMirrorFilterRuleSourcePortRangeArgs> {
    override fun toJava(): com.pulumi.aws.ec2.inputs.TrafficMirrorFilterRuleSourcePortRangeArgs =
        com.pulumi.aws.ec2.inputs.TrafficMirrorFilterRuleSourcePortRangeArgs.builder()
            .fromPort(fromPort?.applyValue({ args0 -> args0 }))
            .toPort(toPort?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TrafficMirrorFilterRuleSourcePortRangeArgs].
 */
@PulumiTagMarker
public class TrafficMirrorFilterRuleSourcePortRangeArgsBuilder internal constructor() {
    private var fromPort: Output<Int>? = null

    private var toPort: Output<Int>? = null

    /**
     * @param value Starting port of the range
     */
    @JvmName("upeiieurulhxkfmy")
    public suspend fun fromPort(`value`: Output<Int>) {
        this.fromPort = value
    }

    /**
     * @param value Ending port of the range
     */
    @JvmName("iyislikevyimtifa")
    public suspend fun toPort(`value`: Output<Int>) {
        this.toPort = value
    }

    /**
     * @param value Starting port of the range
     */
    @JvmName("jmvtnracwwgenole")
    public suspend fun fromPort(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fromPort = mapped
    }

    /**
     * @param value Ending port of the range
     */
    @JvmName("dyumlaawkgrjomff")
    public suspend fun toPort(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.toPort = mapped
    }

    internal fun build(): TrafficMirrorFilterRuleSourcePortRangeArgs =
        TrafficMirrorFilterRuleSourcePortRangeArgs(
            fromPort = fromPort,
            toPort = toPort,
        )
}
